import React from 'react';
import { IOptionProps } from '../../../@types';
import { ILabelProps } from '../../elements/label/Label';
import { IDropdownListProps } from './DropdownList';
import DropdownTrigger from './DropdownTrigger';
export interface IDropdownProps<T> {
    /**
     * Defines the layout and appearance of dropdown
     */
    className?: string;
    /**
     * Defines the layout of the Dropdown contianer
     */
    containerClass?: string;
    /**
     * Defines the disabled state
     */
    disabled?: boolean;
    /**
     * Defines class for dropdown label text
     */
    labelClass?: string;
    /**
     * Defines class for dropdown label container
     */
    labelContainerClass?: string;
    /**
     * Defines the label component layout & helpText
     */
    labelProps?: ILabelProps;
    /**
     * Defines the dropdown label
     */
    labelText?: string;
    /**
     * Defiens the callback handler on option select
     */
    onChange: (option: T) => void;
    /**
     * Defines the options to render
     */
    options: T[];
    /**
     * Defines the options contianer class to define
     * the layout
     */
    optionsContainerClass?: string;
    /**
     * Defines the options container stack order
     */
    optionsZIndex?: string;
    /**
     * Defines the text for no option list item
     */
    noOptionText?: string;
    /**
     * Defines the placeholder text if no option selected
     */
    placeholder?: string;
    /**
     * Defines the option custom component
     */
    renderOptions?: (props: any) => React.ReactChild;
    /**
     * Defines the Dropdown trigger layout
     */
    renderTrigger?: ({ selected, placeholder }: any) => React.ReactChild;
    /**
     * Defines the selected option
     */
    selected?: T;
    /**
     * Defines the trigger icon class
     */
    triggerIconClass?: string;
    /**
     * Defines the validation state
     */
    valid?: boolean;
}
declare const Dropdown: {
    <T extends IOptionProps>({ className, containerClass, disabled, labelClass, labelContainerClass, labelProps, labelText, onChange, options, optionsContainerClass, optionsZIndex, noOptionText, placeholder, renderOptions, renderTrigger, selected, triggerIconClass, valid, ...other }: IDropdownProps<T>): JSX.Element;
    Trigger: typeof DropdownTrigger;
    List: React.ForwardRefExoticComponent<IDropdownListProps<IOptionProps> & React.RefAttributes<HTMLUListElement>>;
    GroupList: React.ForwardRefExoticComponent<Pick<any, string | number | symbol> & React.RefAttributes<HTMLDivElement>>;
};
export default Dropdown;
//# sourceMappingURL=Dropdown.d.ts.map